# PolicyEngine US

PolicyEngine US is a microsimulation model of the United States tax and benefit system.
[PolicyEngine](https://policyengine.org) developed it upon the Python-based [OpenFisca](https://openfisca.org) framework.

Currently it implements most of the federal income tax code, as well as certain benefit programs like the Supplemental Nutrition Assistance Program and the National School Lunch Program.
